#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
    /// </summary>  programmed by phoenix
    [Description("This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.")]
    public class SMAOverUnderPaintBar : Indicator
    {
        #region Variables
        // Wizard generated variables
            private int sMA = 20; // Default setting for SMA
			private bool showpaintbars=true;
        // User defined variables (add any user defined variables below)
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Black), PlotStyle.Line, "SMAvg"));           
			CalculateOnBarClose = true;
			Overlay				= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
            // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
			double ttt = SMA(Close, sMA)[0];
            SMAvg.Set(ttt);
			
			if (Close[0] > SMAvg[0])
			{if (showpaintbars)
					BarColor = Color.Green;
        	}
			else if (Close[0] < SMAvg[0])
			{
				if (showpaintbars)
					BarColor = Color.Red;				
			}
		}

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries SMAvg
        {
            get { return Values[0]; }
        }

        [Description("SMA")]
        [GridCategory("Parameters")]
        public int SMA
        {
            get { return sMA; }
            set { sMA = Math.Max(1, value); }
        }
		
		[Description("Show Paintbar on Candles?")]
		[Category("Parameters")]
		public bool ShowPaintbars
		{
			get { return showpaintbars; }
			set { showpaintbars = value; }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SMAOverUnderPaintBar[] cacheSMAOverUnderPaintBar = null;

        private static SMAOverUnderPaintBar checkSMAOverUnderPaintBar = new SMAOverUnderPaintBar();

        /// <summary>
        /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
        /// </summary>
        /// <returns></returns>
        public SMAOverUnderPaintBar SMAOverUnderPaintBar(bool showPaintbars, int sMA)
        {
            return SMAOverUnderPaintBar(Input, showPaintbars, sMA);
        }

        /// <summary>
        /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
        /// </summary>
        /// <returns></returns>
        public SMAOverUnderPaintBar SMAOverUnderPaintBar(Data.IDataSeries input, bool showPaintbars, int sMA)
        {
            if (cacheSMAOverUnderPaintBar != null)
                for (int idx = 0; idx < cacheSMAOverUnderPaintBar.Length; idx++)
                    if (cacheSMAOverUnderPaintBar[idx].ShowPaintbars == showPaintbars && cacheSMAOverUnderPaintBar[idx].SMA == sMA && cacheSMAOverUnderPaintBar[idx].EqualsInput(input))
                        return cacheSMAOverUnderPaintBar[idx];

            lock (checkSMAOverUnderPaintBar)
            {
                checkSMAOverUnderPaintBar.ShowPaintbars = showPaintbars;
                showPaintbars = checkSMAOverUnderPaintBar.ShowPaintbars;
                checkSMAOverUnderPaintBar.SMA = sMA;
                sMA = checkSMAOverUnderPaintBar.SMA;

                if (cacheSMAOverUnderPaintBar != null)
                    for (int idx = 0; idx < cacheSMAOverUnderPaintBar.Length; idx++)
                        if (cacheSMAOverUnderPaintBar[idx].ShowPaintbars == showPaintbars && cacheSMAOverUnderPaintBar[idx].SMA == sMA && cacheSMAOverUnderPaintBar[idx].EqualsInput(input))
                            return cacheSMAOverUnderPaintBar[idx];

                SMAOverUnderPaintBar indicator = new SMAOverUnderPaintBar();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.ShowPaintbars = showPaintbars;
                indicator.SMA = sMA;
                Indicators.Add(indicator);
                indicator.SetUp();

                SMAOverUnderPaintBar[] tmp = new SMAOverUnderPaintBar[cacheSMAOverUnderPaintBar == null ? 1 : cacheSMAOverUnderPaintBar.Length + 1];
                if (cacheSMAOverUnderPaintBar != null)
                    cacheSMAOverUnderPaintBar.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheSMAOverUnderPaintBar = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SMAOverUnderPaintBar SMAOverUnderPaintBar(bool showPaintbars, int sMA)
        {
            return _indicator.SMAOverUnderPaintBar(Input, showPaintbars, sMA);
        }

        /// <summary>
        /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
        /// </summary>
        /// <returns></returns>
        public Indicator.SMAOverUnderPaintBar SMAOverUnderPaintBar(Data.IDataSeries input, bool showPaintbars, int sMA)
        {
            return _indicator.SMAOverUnderPaintBar(input, showPaintbars, sMA);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SMAOverUnderPaintBar SMAOverUnderPaintBar(bool showPaintbars, int sMA)
        {
            return _indicator.SMAOverUnderPaintBar(Input, showPaintbars, sMA);
        }

        /// <summary>
        /// This indicator will color the price bar red when price closes below the SMA (20 period default) and green when price closes above the SMA.
        /// </summary>
        /// <returns></returns>
        public Indicator.SMAOverUnderPaintBar SMAOverUnderPaintBar(Data.IDataSeries input, bool showPaintbars, int sMA)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SMAOverUnderPaintBar(input, showPaintbars, sMA);
        }
    }
}
#endregion
